@@ -39,33 +39,35 @@ def Rename(image_folder_path, mastersheet, columns, code='', datetime = True):
     image_filenames = glob.glob('*.jpg')
     
     for filename in image_filenames:
-        image = Image.open(filename)
-        im = np.array(image)
-        all_the_info = decode(im)
-        if not all_the_info:
-            continue
-        barcode = all_the_info[0].data
-        d = barcode.decode('ASCII')
-        image_row = df.loc[s==int(d)]
-        print(image_row)
-        info = image_row.iloc[0]
-        temp = []
-        for c in columns:
-            temp.append(info[c])
-        if len(code)>0:
-            temp.append(code)
-        if datetime:
-            exif_data = image._getexif()
-            DT = get_field(exif_data,'DateTime')
-            Time = DT.split()[1]
-            Time = Time.replace(':','-')
-            temp.append(Time)
+        try:
+            image = Image.open(filename)
+            im = np.array(image)
+            all_the_info = decode(im)
+            if not all_the_info:
+                continue
+            barcode = all_the_info[0].data
+            d = barcode.decode('ASCII')
+            image_row = df.loc[s==int(d)]
+            info = image_row.iloc[0]
+            temp = []
+            for c in columns:
+                temp.append(info[c])
+            if len(code)>0:
+                temp.append(code)
+            if datetime:
+                exif_data = image._getexif()
+                DT = get_field(exif_data,'DateTime')
+                Time = DT.split()[1]
+                Time = Time.replace(':','-')
+                temp.append(Time)
 
-        new_name = '_'.join(temp) + '.jpg'
-        print(new_name)
-        dst = new_name
-        src = filename
-        os.rename(src,dst)
+            new_name = '_'.join(temp) + '.jpg'
+            print(new_name)
+            dst = new_name
+            src = filename
+            os.rename(src,dst)
+        except:
+            continue
         
 def identityfxn(a):
     plt.plot(a,a)
